#!/bin/bash 
#---------------------------------------------------
# Run FLEXPART jobs
#---------------------------------------------------
# Guide to use:
#   1. edit the directories, exename, list of stations
#      months and year below
#   2. for slurm set SLURM = 1 otherwise uses nohup  
#   3. the meteorology used for flexpart can be 
#      specified by METEO
#   4. run the script:
#      ./run_flexpart.sh
#---------------------------------------------------

# To run tests reference to current directory
DIR=$PWD
LEN=`expr length $DIR - 17`
ROOTDIR=${DIR:0:$LEN}

echo ${ROOTDIR}

#---------------------------------------------------

# User settings
SLURM=1
#TIMELIM=2-00:00:00
TIMELIM=12:00:00
PARTITION="nilu"
EXENAME=FP_ecmwf_gfortran
METEO=ecmwf
DIRFLEX=${ROOTDIR}/FLEXPART/
DIROPTIONS=${ROOTDIR}/FP_FILES/
STNLIST=(PAL)
MONLIST=(01)
YEAR=2012

#---------------------------------------------------

NSTN=${#STNLIST[@]}
echo "number of stations: "${NSTN}
ARRAYSTN=`seq 1 ${NSTN}`

NMON=${#MONLIST[@]}
echo "number of months: "${NMON}
ARRAYMON=`seq 1 ${NMON}`

# loop over FLEXPART runs

for k in ${ARRAYSTN}
do
  j=`expr $k - 1`
  STN=${STNLIST[$j]}
  for i in ${ARRAYMON} 
  do 
    l=`expr $i - 1`
    MON=${MONLIST[$l]}

    # check RELEASES file exists if not go to next iteration
    echo ${DIROPTIONS}${STN}/${YEAR}${MON}/options/RELEASES
    if [ ! `ls ${DIROPTIONS}${STN}/${YEAR}${MON}/options/RELEASES` ]; then 
      continue
    fi

    # set-up job
    cd ${DIROPTIONS}${STN}/${YEAR}${MON}
    cp ${DIRFLEX}${EXENAME} job_${STN}_${MON}
    rm -f flex.log
    OUTPUT=flex.log
    echo "submitting job for: "${STN}" "${MON}

    if [ ${SLURM} -eq 1 ]; then
    # create submit.sh for submitting to slurm
cat <<EOF > submit.sh
#!/bin/bash
./job_${STN}_${MON}
EOF
sbatch --job-name=job_${STN}_${MON} --partition=${PARTITION} --time=${TIMELIM} --mem-per-cpu=8000 --output=${OUTPUT} submit.sh
      sleep 5 
      rm -f submit.sh
    else
    # use nohup
      nohup ./job_${STN}_${MON} > ${OUTPUT} 
      sleep 5
    fi

  done
done

# the end


